@@ -46,10 +46,14 @@ int main(int argc, char **argv)
                    KAboutData::License_GPL, 
                    "(C) 2004 Tomoaki Murakami", 
                    0, 
-                   0, 
+                   "http://voxstorm.sourceforge.jp/",
                    "solarisphere@yahoo.co.jp");
 
-  about.addAuthor( "Tomoaki Murakami", 0, "solarisphere@yahoo.co.jp" );
+  about.addAuthor(
+                  "Tomoaki Murakami",
+                  0,
+                  "solarisphere@yahoo.co.jp"
+                  "http://voxstorm.sourceforge.jp/");
   KCmdLineArgs::init(argc, argv, &about);
   KCmdLineArgs::addCmdLineOptions( options );
 
