@@ -35,7 +35,7 @@ WFileChooser::WFileChooser(
 
   strBrowserCaption = strDialogCaption;
 
-  LabelCaption = new QLabel(i18n(strCaption), this);
+  LabelCaption = new QLabel(strCaption, this);
   LineEditFileName = new KLineEdit(this);
   LineEditFileName->setMinimumWidth(60);
   connect(LineEditFileName, SIGNAL(textChanged(const QString&)),
