@@ -37,6 +37,47 @@
 
 WVoxStorm::WVoxStorm(QWidget *WidgetParent, const char *cName)
   : KMainWindow(WidgetParent, cName)
+{
+  initialize();
+
+  bDirty = false;
+  slotNew();
+  bDirty = true;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+WVoxStorm::WVoxStorm(
+  const QString& strFileName, 
+  QWidget* WidgetParent, 
+  const char* cName)
+  : KMainWindow(WidgetParent, cName)
+{
+  initialize();
+
+  loadFile(strFileName);
+  bDirty = false;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+WVoxStorm::~WVoxStorm()
+{
+  writeConfigurationFile();
+
+  if ( pDocVox != NULL ) {
+    delete pDocVox;
+    pDocVox = new QDomDocument;
+  }
+
+  delete ToggleActionRec;
+  delete ToggleActionInteractive;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WVoxStorm::initialize()
 {
   setupActions();
   setupStatusBar();
@@ -77,32 +118,11 @@ WVoxStorm::WVoxStorm(QWidget *WidgetParent, const char *cName)
   connect(&EcaIAManager, SIGNAL(messageGenerated(const QString&)),
           VoxBase, SLOT(slotWriteConsoleMessage(const QString&)));
 
-  bDirty = false;
-  
-  slotNew();
-
-  bDirty = true;
-
   pDocVox = NULL;
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
-WVoxStorm::~WVoxStorm()
-{
-  writeConfigurationFile();
-
-  if ( pDocVox != NULL ) {
-    delete pDocVox;
-    pDocVox = new QDomDocument;
-  }
-
-  delete ToggleActionRec;
-  delete ToggleActionInteractive;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 void 
 WVoxStorm::readConfigurationFile()
 {
@@ -374,7 +394,10 @@ WVoxStorm::setupActions()
 void
 WVoxStorm::setupStatusBar()
 {
-  statusBar()->insertItem("", 0, 1, false);
+  LabelStatusBar = new QLabel("xxxxxxxxxxxxxxxxxxxxx", this);
+  LabelStatusBar->setMinimumSize(LabelStatusBar->sizeHint());
+  LabelStatusBar->setText("");
+  statusBar()->addWidget(LabelStatusBar);
   statusBar()->setSizeGripEnabled(true);
   statusBar()->show();
 }
@@ -472,13 +495,20 @@ WVoxStorm::createNewUntitledName() const
 void
 WVoxStorm::loadFile(const QString& strFileName)
 {
+  QApplication::setOverrideCursor(waitCursor);
+  LabelStatusBar->setText("Loading...");
+
   QDomDocument doc;
   QFile File(strFileName);
   if ( !File.open(IO_ReadOnly) ) {
+    LabelStatusBar->setText("");
+    QApplication::restoreOverrideCursor();
     return;
   }
   if ( !doc.setContent(&File) ) {
     File.close();
+    LabelStatusBar->setText("");
+    QApplication::restoreOverrideCursor();
     return;
   }
   File.close();
@@ -492,6 +522,9 @@ WVoxStorm::loadFile(const QString& strFileName)
   VoxBase->addTracks(eleRoot.firstChild());
 
   enterIAMode(ToggleActionInteractive->isChecked());
+
+  LabelStatusBar->setText("");
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -499,6 +532,9 @@ WVoxStorm::loadFile(const QString& strFileName)
 void
 WVoxStorm::saveFile(const QString& strFileName)
 {
+  QApplication::setOverrideCursor(waitCursor);
+  LabelStatusBar->setText("Saving...");
+
   if ( pDocVox != NULL ) {
     delete pDocVox;
   }
@@ -522,6 +558,8 @@ WVoxStorm::saveFile(const QString& strFileName)
   if ( !File.open(IO_WriteOnly) ) {
     delete pDocVox;
     pDocVox = NULL;
+    LabelStatusBar->setText("");
+    QApplication::restoreOverrideCursor();
     return;
   }
   QTextStream out(&File);
@@ -530,6 +568,9 @@ WVoxStorm::saveFile(const QString& strFileName)
   pDocVox = NULL;
 
   bDirty = false;
+
+  LabelStatusBar->setText("");
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -609,7 +650,9 @@ WVoxStorm::slotOpen()
   if ( maybeSave() ) {
     KURL url = KFileDialog::getOpenURL(
                  QString::null, 
-                 "*.voxs|VoxStorm session files\n*|All files");
+                 "*.voxs|VoxStorm session files (.voxs)\n*|All files", 
+                 NULL, 
+                 "Open VoxStorm session file");
     if ( !url.isEmpty() ) {
       if ( url.isLocalFile() ) {
 	loadFile(url.path());	
@@ -640,9 +683,9 @@ bool
 WVoxStorm::slotSaveAs()
 {
   KFileDialog Dialog(QString::null,
-                     "*.voxs|VoxStorm session files", 
+                     "*.voxs|VoxStorm session files (.voxs)", 
                      NULL,
-                     "Save File", 
+                     "Save VoxStorm session file", 
                      true);
   Dialog.exec();
   QString strFileName = Dialog.selectedFile();
@@ -679,6 +722,11 @@ void
 WVoxStorm::slotPlay()
 {
   QApplication::setOverrideCursor(waitCursor);
+  if ( ToggleActionRec->isChecked() ) {
+    LabelStatusBar->setText("Recording...");
+  } else {
+    LabelStatusBar->setText("Playing...");
+  }
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotRemoveAllChains();
     int nCount = VoxBase->getTrackCount();
@@ -688,11 +736,9 @@ WVoxStorm::slotPlay()
     }
 
     EcaIAManager.slotPlay(ToggleActionRec->isChecked());
-    if ( EcaIAManager.isPlaying() ) { // success playing
-      ToggleActionRec->setEnabled(false);
-      VoxBase->slotSetEnabledWidgets(WVoxBase::Play);
-      VoxBase->slotChangeMessageTab(WVoxBase::Console);
-    }
+    ToggleActionRec->setEnabled(false);
+    VoxBase->slotSetEnabledWidgets(WVoxBase::Play);
+    VoxBase->slotChangeMessageTab(WVoxBase::Console);
   } else {
   }
   QApplication::restoreOverrideCursor();
@@ -983,6 +1029,7 @@ WVoxStorm::slotFinish()
   }
   VoxBase->slotSetEnabledWidgets(WVoxBase::Stop);
   ToggleActionRec->setEnabled(true);
+  LabelStatusBar->setText("");
 }
 
 /////////////////////////////////////////////////////////////////////////////
